==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneCloseEventArgsDetailDescriptionMetadata } from "./WebPaneCloseEventArgsDetailDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneCloseEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneCloseEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
                WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneCloseEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneCloseEventArgsDescriptionMetadata.a);
            WebPaneCloseEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneCloseEventArgsDetail");
        }
        static d(a) {
            WebPaneCloseEventArgsDescriptionMetadata.b(a);
            a.ad("WebPaneCloseEventArgs", () => new WebPaneCloseEventArgsDescription());
            a.ac("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneCloseEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneCloseEventArgsDetailDescriptionMetadata } from "./WebPaneCloseEventArgsDetailDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneCloseEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneCloseEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
                WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneCloseEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneCloseEventArgsDescriptionMetadata.a);
            WebPaneCloseEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneCloseEventArgsDetail");
        }
        static d(a) {
            WebPaneCloseEventArgsDescriptionMetadata.b(a);
            a.ae("WebPaneCloseEventArgs", () => new WebPaneCloseEventArgsDescription());
            a.ad("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneCloseEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
})();
